@@ -1,5 +1,5 @@
 #define banner  \
-"hbf2gf (CJK ver. 4.6.0)" \
+"hbf2gf (CJK ver. 4.8.0)" \
  \
 
 #define TRUE 1
@@ -100,25 +100,25 @@
 #define VALID_SUBCODE 1 \
 
 /*4:*/
-#line 176 "hbf2gf.w"
+#line 193 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 /*10:*/
-#line 396 "hbf2gf.w"
+#line 413 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
-#include <ctype.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <time.h>
+#include <ctype.h> 
+#include <stdio.h> 
+#include <stdlib.h> 
+#include <string.h> 
+#include <time.h> 
 #ifdef TM_IN_SYS_TIME
-#include <sys/time.h>
+#include <sys/time.h> 
 #endif
 #include "hbf.h"
 
 
 
 /*:10*//*69:*/
-#line 2466 "hbf2gf.w"
+#line 2483 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 #if defined(HAVE_LIBKPATHSEA)
 #ifdef VERY_OLD_KPATHSEA
@@ -137,46 +137,46 @@
 #endif
 
 /*:69*/
-#line 177 "hbf2gf.w"
+#line 194 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 /*11:*/
-#line 414 "hbf2gf.w"
+#line 431 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void write_file(void);
 
 
 /*:11*//*13:*/
-#line 476 "hbf2gf.w"
+#line 493 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void write_pre(void);
 
 
 /*:13*//*16:*/
-#line 564 "hbf2gf.w"
+#line 581 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void write_data(void);
 
 
 /*:16*//*20:*/
-#line 675 "hbf2gf.w"
+#line 692 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void write_post(void);
 
 
 /*:20*//*25:*/
-#line 819 "hbf2gf.w"
+#line 836 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void fputl(long,FILE*);
 
 
 /*:25*//*29:*/
-#line 982 "hbf2gf.w"
+#line 999 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void make_pixel_array(void);
 
 
 /*:29*//*36:*/
-#line 1210 "hbf2gf.w"
+#line 1227 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 #ifdef __GNUC__
 __inline__
@@ -185,7 +185,7 @@ void read_row(unsigned char*);
 
 
 /*:36*//*39:*/
-#line 1262 "hbf2gf.w"
+#line 1279 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 #ifdef __GNUC__
 __inline__
@@ -194,55 +194,55 @@ void write_row(unsigned char*);
 
 
 /*:39*//*41:*/
-#line 1317 "hbf2gf.w"
+#line 1334 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void write_coding(void);
 
 
 /*:41*//*45:*/
-#line 1478 "hbf2gf.w"
+#line 1495 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void write_pl(void);
 
 
 /*:45*//*47:*/
-#line 1575 "hbf2gf.w"
+#line 1592 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void write_ovp(void);
 
 
 /*:47*//*50:*/
-#line 1720 "hbf2gf.w"
+#line 1737 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void write_job(void);
 
 
 /*:50*//*54:*/
-#line 1969 "hbf2gf.w"
+#line 1986 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void read_config(void);
 
 
 /*:54*//*64:*/
-#line 2300 "hbf2gf.w"
+#line 2317 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 int fsearch(char*);
 
 
 /*:64*//*67:*/
-#line 2440 "hbf2gf.w"
+#line 2457 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void config_error(char*);
 
 
 /*:67*//*71:*/
-#line 2500 "hbf2gf.w"
+#line 2517 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 char*TeX_search_version(void);
 
 
 /*:71*//*74:*/
-#line 2535 "hbf2gf.w"
+#line 2552 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 #ifdef HAVE_EMTEXDIR
 extern int setup_list(struct emtex_dir*,char*,const char*,unsigned);
@@ -252,17 +252,17 @@ char*file_find(char*,struct emtex_dir*);
 
 
 /*:74*//*79:*/
-#line 2632 "hbf2gf.w"
+#line 2649 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 char*TeX_search_cfg_file(char*);
 char*TeX_search_hbf_file(char*);
 
 
 /*:79*/
-#line 178 "hbf2gf.w"
+#line 195 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 /*2:*/
-#line 112 "hbf2gf.w"
+#line 129 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 int nmb_files= -1;
 int unicode= FALSE;
@@ -303,7 +303,7 @@ int end_of_file= FALSE;
 
 
 /*:2*//*15:*/
-#line 523 "hbf2gf.w"
+#line 540 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 long char_adr[256];
 long*char_adr_p;
@@ -345,7 +345,7 @@ int dot_count;
 
 
 /*:15*//*19:*/
-#line 652 "hbf2gf.w"
+#line 669 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 char coding[STRING_LENGTH+1];
 char comment[STRING_LENGTH+1];
@@ -364,7 +364,7 @@ double ppp_y;
 
 
 /*:19*//*27:*/
-#line 859 "hbf2gf.w"
+#line 876 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 HBF_CHAR code;
 const unsigned char*bitmap;
@@ -387,13 +387,13 @@ long s_mag_x,s_mag_y,s_slant;
 
 
 /*:27*//*38:*/
-#line 1257 "hbf2gf.w"
+#line 1274 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 int threshold= 128;
 
 
 /*:38*//*49:*/
-#line 1709 "hbf2gf.w"
+#line 1726 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 char job_extension[EXTENSION_LENGTH+1];
 char rm_command[STRING_LENGTH+1];
@@ -405,13 +405,13 @@ int ofm_file= FALSE;
 
 
 /*:49*//*53:*/
-#line 1964 "hbf2gf.w"
+#line 1981 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 char Buffer[STRING_LENGTH+1];
 
 
 /*:53*//*58:*/
-#line 2082 "hbf2gf.w"
+#line 2099 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 int offset_x;
 int offset_y;
@@ -420,13 +420,13 @@ HBF_CHAR user_min_char;
 int have_min_char= FALSE;
 
 /*:58*//*60:*/
-#line 2239 "hbf2gf.w"
+#line 2256 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 HBF_CHAR min_char,max_char;
 
 
 /*:60*//*62:*/
-#line 2266 "hbf2gf.w"
+#line 2283 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 char b2_codes[256];
 unsigned char min_2_byte,max_2_byte;
@@ -434,7 +434,7 @@ int nmb_2_bytes= 0;
 
 
 /*:62*//*70:*/
-#line 2484 "hbf2gf.w"
+#line 2501 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 #if defined(HAVE_LIBKPATHSEA)
 #ifdef KPSEDLL
@@ -451,7 +451,7 @@ char no_version_string[]= "no search library";
 
 
 /*:70*//*73:*/
-#line 2528 "hbf2gf.w"
+#line 2545 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 #ifdef HAVE_EMTEXDIR
 struct emtex_dir cfg_path,hbf_path;
@@ -459,13 +459,13 @@ struct emtex_dir cfg_path,hbf_path;
 
 
 /*:73*//*76:*/
-#line 2574 "hbf2gf.w"
+#line 2591 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 char name_buffer[FILE_NAME_LENGTH+1];
 
 
 /*:76*/
-#line 179 "hbf2gf.w"
+#line 196 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 
 
@@ -476,7 +476,7 @@ char*argv[];
 {char*p;
 
 /*78:*/
-#line 2596 "hbf2gf.w"
+#line 2613 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 #if defined(HAVE_LIBKPATHSEA)
 #ifdef OLD_KPATHSEA
@@ -506,16 +506,16 @@ exit(1);
 
 
 /*:78*/
-#line 188 "hbf2gf.w"
+#line 205 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 
 /*7:*/
-#line 295 "hbf2gf.w"
+#line 312 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 if(argc==2)
 {if(strcmp(argv[1],"--help")==0)
 /*6:*/
-#line 276 "hbf2gf.w"
+#line 293 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 {printf(USAGE);
 exit(0);
@@ -523,11 +523,11 @@ exit(0);
 
 
 /*:6*/
-#line 298 "hbf2gf.w"
+#line 315 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 else if(strcmp(argv[1],"--version")==0)
 /*5:*/
-#line 249 "hbf2gf.w"
+#line 266 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 {printf("\n");
 printf(banner);
@@ -538,11 +538,11 @@ exit(0);
 
 
 /*:5*/
-#line 300 "hbf2gf.w"
+#line 317 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 }
 
-while(argc>1)
+while(argc> 1)
 {p= argv[1];
 if(p[0]!='-')
 break;
@@ -568,7 +568,7 @@ fprintf(stderr,"Try `hbf2gf --help' for more information.\n");
 exit(1);
 }
 }
-else if(argc<2||argc>4)
+else if(argc<2||argc> 4)
 {fprintf(stderr,"Invalid number of parameters.\n");
 fprintf(stderr,"Try `hbf2gf --help' for more information.\n");
 exit(1);
@@ -576,7 +576,7 @@ exit(1);
 
 
 /*:7*/
-#line 190 "hbf2gf.w"
+#line 207 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 
 if(!quiet)
@@ -585,10 +585,10 @@ printf("\n%s\n\n",banner);
 strncpy(config_file,argv[1],FILE_NAME_LENGTH);
 config_file[FILE_NAME_LENGTH]= '\0';
 
-if(argc>2||testing)
+if(argc> 2||testing)
 {int l= strlen(config_file);
 
-if(l>2)
+if(l> 2)
 config_file[l-2]= '\0';
 
 else
@@ -605,7 +605,7 @@ read_config();
 
 if(mf_like)
 /*8:*/
-#line 340 "hbf2gf.w"
+#line 357 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 {if(unicode)
 file_number= (int)strtol(&argv[1][strlen(argv[1])-2],
@@ -619,25 +619,25 @@ if(x_resolution<PRINTER_MIN_RES_X)
 exit(1);
 }
 
-if(argc>3)
+if(argc> 3)
 {y_scale= atof(argv[3]);
 if(y_scale<0.01)
 {fprintf(stderr,
 "Invalid vertical scaling factor or resolution\n");
 exit(1);
 }
-if(y_scale>10.0)
+if(y_scale> 10.0)
 y_scale= (double)x_resolution/y_scale;
 }
 }
 
 
 /*:8*/
-#line 217 "hbf2gf.w"
+#line 234 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 
 /*28:*/
-#line 891 "hbf2gf.w"
+#line 908 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 {int col,offset;
 
@@ -672,11 +672,11 @@ tfm_output_size_x= input_size_x*mag_x/
 (dpi_x/72.27)/design_size;
 tfm_output_size_y= input_size_y*mag_y/
 (dpi_y/72.27)/design_size;
-if(pk_output_size_x>MAX_CHAR_SIZE)
+if(pk_output_size_x> MAX_CHAR_SIZE)
 {fprintf(stderr,"Output character box width too big\n");
 exit(1);
 }
-if(pk_output_size_y>MAX_CHAR_SIZE)
+if(pk_output_size_y> MAX_CHAR_SIZE)
 {fprintf(stderr,"Output character box height too big\n");
 exit(1);
 }
@@ -707,7 +707,7 @@ while(!b2_codes[code++&0xFF])
 
 ;
 
-if(code>max_char)
+if(code> max_char)
 {fprintf(stderr,"Invalid subfile number\n");
 exit(1);
 }
@@ -720,11 +720,11 @@ s_slant= slant*SCALE;
 
 
 /*:28*/
-#line 219 "hbf2gf.w"
+#line 236 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 
 /*9:*/
-#line 375 "hbf2gf.w"
+#line 392 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 {int j,max_numb;
 
@@ -746,7 +746,7 @@ nmb_files= j;
 
 
 /*:9*/
-#line 221 "hbf2gf.w"
+#line 238 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 
 if(tfm_files)
@@ -764,7 +764,7 @@ return 0;
 
 
 /*:4*//*12:*/
-#line 422 "hbf2gf.w"
+#line 439 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void write_file(void)
 {char output_file[FILE_NAME_LENGTH+1];
@@ -808,7 +808,7 @@ write_data();
 
 
 /*:12*//*14:*/
-#line 483 "hbf2gf.w"
+#line 500 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void write_pre(void)
 {char out_s[40],s[20];
@@ -831,7 +831,7 @@ fputs(out_s,out);
 
 
 /*:14*//*17:*/
-#line 569 "hbf2gf.w"
+#line 586 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void write_data(void)
 {dot_count= 0;
@@ -839,7 +839,7 @@ char_adr_p= char_adr;
 
 for(last_char= 0;(last_char<256)&&!end_of_file;last_char++)
 /*18:*/
-#line 594 "hbf2gf.w"
+#line 611 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 {if(dot_count++%10==0)
 if(pk_files&&!quiet)
@@ -883,13 +883,13 @@ fputc(EOC,out);
 
 
 /*:18*/
-#line 575 "hbf2gf.w"
+#line 592 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 }
 
 
 /*:17*//*21:*/
-#line 680 "hbf2gf.w"
+#line 697 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void write_post(void)
 {long special_adr;
@@ -917,7 +917,7 @@ tfm_width= (tfm_output_size_x+2*tfm_offset_x)*_2_20;
 
 
 /*22:*/
-#line 726 "hbf2gf.w"
+#line 743 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 special_adr= ftell(out);
 
@@ -935,10 +935,10 @@ fputs(comment,out);
 
 
 /*:22*/
-#line 706 "hbf2gf.w"
+#line 723 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 /*23:*/
-#line 755 "hbf2gf.w"
+#line 772 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 post_adr= ftell(out);
 fputc(POST,out);
@@ -977,10 +977,10 @@ fputl(*char_adr_p++,out);
 
 
 /*:23*/
-#line 707 "hbf2gf.w"
+#line 724 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 /*24:*/
-#line 806 "hbf2gf.w"
+#line 823 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 fputc(POSTPOST,out);
 fputl(post_adr,out);
@@ -992,13 +992,13 @@ fputc(POSTPOST_ID,out);
 
 
 /*:24*/
-#line 708 "hbf2gf.w"
+#line 725 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 }
 
 
 /*:21*//*26:*/
-#line 824 "hbf2gf.w"
+#line 841 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void fputl(num,f)
 long num;
@@ -1012,7 +1012,7 @@ fputc(num,f);
 
 
 /*:26*//*30:*/
-#line 987 "hbf2gf.w"
+#line 1004 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void make_pixel_array(void)
 {unsigned char*prP;
@@ -1050,7 +1050,7 @@ if(!bitmap)
 empty_char= TRUE;
 else
 /*31:*/
-#line 1046 "hbf2gf.w"
+#line 1063 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 {if(pk_output_size_y==input_size_y)
 temp_prP= prP;
@@ -1058,7 +1058,7 @@ temp_prP= prP;
 curr_row= input_size_y-1;
 for(row= 0;row<pk_output_size_y;++row)
 {/*32:*/
-#line 1060 "hbf2gf.w"
+#line 1077 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 if(pk_output_size_y==input_size_y)
 
@@ -1080,7 +1080,7 @@ need_to_read_row= 1;
 }
 
 /*33:*/
-#line 1087 "hbf2gf.w"
+#line 1104 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 if(need_to_read_row)
 if(rows_read<input_size_y)
@@ -1096,7 +1096,7 @@ col<input_size_x;++col,++xP,++nxP)
 
 g= grP[col]+frac_row_to_fill*(*xP);
 g/= SCALE;
-if(g>PIXEL_MAXVAL)
+if(g> PIXEL_MAXVAL)
 g= PIXEL_MAXVAL;
 
 *nxP= g;
@@ -1112,16 +1112,16 @@ frac_row_to_fill= SCALE;
 
 
 /*:33*/
-#line 1080 "hbf2gf.w"
+#line 1097 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 }
 
 
 /*:32*/
-#line 1052 "hbf2gf.w"
+#line 1069 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 /*34:*/
-#line 1128 "hbf2gf.w"
+#line 1145 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 if(pk_width==input_size_x&&s_slant==0)
 
@@ -1141,7 +1141,7 @@ while(frac_col_left>=frac_col_to_fill)
 frac_col_left-= frac_col_to_fill;
 }
 
-if(frac_col_left>0)
+if(frac_col_left> 0)
 frac_col_to_fill-= frac_col_left;
 
 for(col= 0,xP= temp_prP;col<input_size_x;++col,++xP)
@@ -1154,7 +1154,7 @@ g= HALFSCALE;
 
 g+= frac_col_to_fill*(*xP);
 g/= SCALE;
-if(g>PIXEL_MAXVAL)
+if(g> PIXEL_MAXVAL)
 g= PIXEL_MAXVAL;
 
 *nxP= g;
@@ -1163,7 +1163,7 @@ frac_col_to_fill= SCALE;
 need_col= 1;
 }
 
-if(frac_col_left>0)
+if(frac_col_left> 0)
 {if(need_col)
 {++nxP;
 g= HALFSCALE;
@@ -1176,16 +1176,16 @@ frac_col_to_fill-= frac_col_left;
 }
 
 /*35:*/
-#line 1186 "hbf2gf.w"
+#line 1203 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
-if(frac_col_to_fill>0)
+if(frac_col_to_fill> 0)
 {--xP;
 g+= frac_col_to_fill*(*xP);
 }
 
 if(!need_col)
 {g/= SCALE;
-if(g>PIXEL_MAXVAL)
+if(g> PIXEL_MAXVAL)
 g= PIXEL_MAXVAL;
 *nxP= g;
 }
@@ -1196,20 +1196,20 @@ write_row(new_prP);
 
 
 /*:35*/
-#line 1181 "hbf2gf.w"
+#line 1198 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 }
 
 
 /*:34*/
-#line 1054 "hbf2gf.w"
+#line 1071 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 }
 }
 
 
 /*:31*/
-#line 1023 "hbf2gf.w"
+#line 1040 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 }
 }
@@ -1233,7 +1233,7 @@ goto again;
 
 
 /*:30*//*37:*/
-#line 1218 "hbf2gf.w"
+#line 1235 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 #ifdef __GNUC__
 __inline__
@@ -1270,7 +1270,7 @@ bitshift= 7;
 
 
 /*:37*//*40:*/
-#line 1270 "hbf2gf.w"
+#line 1287 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 #ifdef __GNUC__
 __inline__
@@ -1288,7 +1288,7 @@ for(col= 0,xP= pixelrow;col<pk_output_size_x;++col,++xP)
 
 
 /*:40*//*42:*/
-#line 1325 "hbf2gf.w"
+#line 1342 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void write_coding(void)
 {register int count,skip;
@@ -1305,7 +1305,7 @@ goto start;
 
 while(y<pk_output_size_y)
 {/*43:*/
-#line 1349 "hbf2gf.w"
+#line 1366 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 count= 0;
 x= 0;
@@ -1374,11 +1374,11 @@ continue;
 
 
 /*:43*/
-#line 1340 "hbf2gf.w"
+#line 1357 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 start:
 /*44:*/
-#line 1417 "hbf2gf.w"
+#line 1434 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 while(x<pk_output_size_x)
 {if(*cp==paint)
@@ -1419,7 +1419,7 @@ paint= WHITE;
 
 
 /*:44*/
-#line 1342 "hbf2gf.w"
+#line 1359 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 y++;
 }
@@ -1427,7 +1427,7 @@ y++;
 
 
 /*:42*//*46:*/
-#line 1483 "hbf2gf.w"
+#line 1500 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void write_pl(void)
 {int i,pos;
@@ -1481,7 +1481,7 @@ sc= 16;
 pos= 18;
 
 fprintf(out,"\n");
-while(i>0)
+while(i> 0)
 {t|= ((long)(*(unsigned char*)s++))<<sc;
 sc-= 8;
 if(sc<0)
@@ -1517,7 +1517,7 @@ fclose(out);
 
 
 /*:46*//*48:*/
-#line 1580 "hbf2gf.w"
+#line 1597 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void write_ovp(void)
 {int c,i,nmb_subfonts,remainder,count,pos;
@@ -1570,7 +1570,7 @@ sc= 16;
 pos= 18;
 
 fprintf(out,"\n");
-while(i>0)
+while(i> 0)
 {t|= ((long)(*(unsigned char*)s++))<<sc;
 sc-= 8;
 if(sc<0)
@@ -1632,7 +1632,7 @@ fclose(out);
 
 
 /*:48*//*51:*/
-#line 1725 "hbf2gf.w"
+#line 1742 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void write_job(void)
 {FILE*out;
@@ -1718,7 +1718,7 @@ fclose(out);
 
 
 /*:51*//*55:*/
-#line 1977 "hbf2gf.w"
+#line 1994 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void read_config(void)
 {HBF_BBOX*boxp;
@@ -1726,7 +1726,7 @@ char*real_config_file;
 
 
 /*56:*/
-#line 2029 "hbf2gf.w"
+#line 2046 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 {int i,lastext= -1;
 
@@ -1744,7 +1744,7 @@ strcat(config_file,".cfg");
 
 
 /*:56*/
-#line 1983 "hbf2gf.w"
+#line 2000 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 
 real_config_file= TeX_search_cfg_file(config_file);
@@ -1779,7 +1779,7 @@ exit(0);
 }
 
 /*57:*/
-#line 2046 "hbf2gf.w"
+#line 2063 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 {char hbf_header[STRING_LENGTH+1];
 char*real_hbf_header;
@@ -1816,10 +1816,10 @@ strcpy(output_name,Buffer);
 
 
 /*:57*/
-#line 2016 "hbf2gf.w"
+#line 2033 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 /*59:*/
-#line 2090 "hbf2gf.w"
+#line 2107 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 {if(fsearch("nmb_files"))
 nmb_files= atoi(Buffer);
@@ -1848,7 +1848,7 @@ long_extension= FALSE;
 
 if(fsearch("slant"))
 slant= atof(Buffer);
-if(slant<0.0||slant>1.0)
+if(slant<0.0||slant> 1.0)
 {fprintf(stderr,"Invalid slant\n");
 exit(1);
 }
@@ -1961,11 +1961,11 @@ job_extension[EXTENSION_LENGTH]= '\0';
 
 
 /*:59*/
-#line 2017 "hbf2gf.w"
+#line 2034 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 
 /*61:*/
-#line 2244 "hbf2gf.w"
+#line 2261 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 {const void*cp;
 HBF_CHAR dummy;
@@ -1980,10 +1980,10 @@ min_char= user_min_char;
 
 
 /*:61*/
-#line 2019 "hbf2gf.w"
+#line 2036 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 /*63:*/
-#line 2273 "hbf2gf.w"
+#line 2290 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 {const void*b2r;
 unsigned char dummy;
@@ -2006,7 +2006,7 @@ nmb_2_bytes++;
 
 
 /*:63*/
-#line 2020 "hbf2gf.w"
+#line 2037 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 
 fclose(config);
@@ -2014,7 +2014,7 @@ fclose(config);
 
 
 /*:55*//*65:*/
-#line 2305 "hbf2gf.w"
+#line 2322 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 int fsearch(search_string)
 char*search_string;
@@ -2063,7 +2063,7 @@ P= temp_buffer;
 while((Ch= fgetc(config))==' '||Ch=='\t')
 
 ;
-while(Ch!='\n'&&--count>0&&Ch!=EOF)
+while(Ch!='\n'&&--count> 0&&Ch!=EOF)
 {*P++= Ch;
 Ch= fgetc(config);
 }
@@ -2071,13 +2071,13 @@ Ch= fgetc(config);
 
 if(*temp_buffer)
 /*66:*/
-#line 2385 "hbf2gf.w"
+#line 2402 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 {P= temp_buffer;
 Buf_p= Buffer;
 count= STRING_LENGTH-1;
 
-while(*P&&count>0)
+while(*P&&count> 0)
 {env_p= env_name;
 
 if(*P=='$')
@@ -2108,7 +2108,7 @@ break;
 
 env_value= getenv(env_name);
 if(env_value)
-{while(*env_value&&count>0)
+{while(*env_value&&count> 0)
 {*(Buf_p++)= *(env_value++);
 count--;
 }
@@ -2124,7 +2124,7 @@ count--;
 
 
 /*:66*/
-#line 2360 "hbf2gf.w"
+#line 2377 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 else
 *Buffer= '\0';
@@ -2134,7 +2134,7 @@ return(*Buffer)?1:0;
 
 
 /*:65*//*68:*/
-#line 2445 "hbf2gf.w"
+#line 2462 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 void config_error(message)
 char*message;
@@ -2147,7 +2147,7 @@ exit(1);
 
 
 /*:68*//*72:*/
-#line 2505 "hbf2gf.w"
+#line 2522 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 char*TeX_search_version(void)
 {
@@ -2169,7 +2169,7 @@ return no_version_string;
 
 
 /*:72*//*75:*/
-#line 2547 "hbf2gf.w"
+#line 2564 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 #ifdef HAVE_EMTEXDIR
 int dir_setup(ed,env,dir,flags)
@@ -2197,7 +2197,7 @@ return TRUE;
 
 
 /*:75*//*77:*/
-#line 2579 "hbf2gf.w"
+#line 2596 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 char*file_find(name,list)
 char*name;
@@ -2212,7 +2212,7 @@ return NULL;
 
 
 /*:77*//*80:*/
-#line 2638 "hbf2gf.w"
+#line 2655 "/home/wl/git/cjk/cjk-4.8.0/utils/hbf2gf/hbf2gf.w"
 
 #if defined(HAVE_LIBKPATHSEA)
 char*TeX_search_cfg_file(name)
